@@ -202,38 +202,6 @@ def completeness_facvisits(df, Timed = False):
 
 ################################################################
 
-
-def tattle(hosp,issue,num,frac):
-    '''
-    Function that writes to a "Tattle" log.
-    If you ever find improper formatting/issues that screw up your code, run this
-         on your scripts and want to tattle about it.  Will send to a tattle log.
-
-    Inputs
-    -------
-    - facility
-    - brief issue description (try to be uniform)
-    - number of issues
-    - fraction of total cases that have issues
-    
-    Outputs
-    -------
-    None (simply writes to file)
-    '''
-    # Clean up
-    frac = round(frac,3)
-    num = int(num)
-    issue = str(issue)
-    hosp = str(hosp)
-    
-    cols = ['Facility','Issue','Num_Issues','Total_issue_percent']
-    newrow = pd.DataFrame(columns=cols)
-    newrow.loc[0] = [hosp,issue,num,frac]
-    newrow.to_csv('../data/processed/tattle_sheet.csv',mode='a',header=False, index=False)
-    
-
-################################################################
-
 def to_hours(item):
     '''
     Takes a datetime object and converts them to the time in hours,
@@ -876,6 +844,7 @@ def NSSP_Element_Grabber(data,Timed = True, Priority_only=False, outfile='None')
         If True, only gives priority 1 or 2 elements
     outfile:  Default is 'None':
         Replace with file name for dataframe to be wrote to as csv
+        Will be located in working directory.
         DO NOT INCLUDE .csv IF YOU CHOOSE TO MAKE ONE
     
     Returns
@@ -966,7 +935,7 @@ def NSSP_Element_Grabber(data,Timed = True, Priority_only=False, outfile='None')
     # If they want an output file...
     if outfile!='None':
         # Specify output path and add csv bit.
-        outpath = '../data/processed/'+outfile+'.csv'
+        outpath = outfile+'.csv'
         # No index
         df.to_csv(outpath, index=False)
     
@@ -1002,7 +971,7 @@ def priority_cols(df, priority='both', extras=None, drop_cols=None):
     ------------
     -import pandas as pd
     '''
-    reader = pd.read_excel('../data/processed/NSSP_Element_Reader.xlsx') 
+    reader = pd.read_excel('NSSP_Element_Reader.xlsx') 
    
     # There is a chance that the user removed priority columns from the input dataframe for their own reasons.
     #     Therefore we only want to look at cases where the input dataframe columns match the reader processed column.
@@ -1078,7 +1047,7 @@ def validity_check(df, Timed=True):
     
     
     # Read in the validity key
-    key = pd.read_excel('../data/processed/NSSP_Validity_Reader.xlsx')
+    key = pd.read_excel('NSSP_Validity_Reader.xlsx')
 
     # There is a chance that the user had decided to get rid of columns we typically check for validity.
     #      Therefore we need to only loop through 'key' rows that match our input dataframe's columns.
@@ -1192,7 +1161,7 @@ def Visualize_Facility_DQ(df, fac_name, hide_yticks = False, Timed = True):
     hosp_visits = df[df.FACILITY_NAME==fac_name]
 
     # Read in our validity key
-    key = pd.read_excel('../data/processed/NSSP_Validity_Reader.xlsx')
+    key = pd.read_excel('NSSP_Validity_Reader.xlsx')
 
     # There is a chance that the user had decided to get rid of columns we typically check for validity.
     #      Therefore we need to only loop through 'key' rows that match our input dataframe's columns.
@@ -1475,7 +1444,7 @@ def issues_in_messages(df, Timed=True, combine_issues_on_message = False, split_
     ########################################################################################################
 
     # Load our key and set its index
-    key = pd.read_excel('../data/processed/Message_Corrector_Key.xlsx')
+    key = pd.read_excel('Message_Corrector_Key.xlsx')
     key = key.set_index('Element')
 
     # Initialize df_out
@@ -1791,14 +1760,14 @@ def validity_and_completeness_report(df,description='long',visit_count=False,out
     #####################################################################################################################
 
     if description == 'long':
-        key = pd.read_excel('../data/processed/Message_Corrector_Key.xlsx')
+        key = pd.read_excel('Message_Corrector_Key.xlsx')
         key = key.set_index('Element')
         for i in np.arange(0,len(empty)):
             el = empty.loc[i,'Element']
             empty.loc[i,'Description'] = key.loc[el,'Description']
 
     elif description == 'short':
-        key = pd.read_excel('../data/processed/NSSP_Element_Reader.xlsx')
+        key = pd.read_excel('NSSP_Element_Reader.xlsx')
         key = key.set_index('Processed Column')
         for i in np.arange(0,len(empty)):
             el = empty.loc[i,'Element']
@@ -1811,11 +1780,11 @@ def validity_and_completeness_report(df,description='long',visit_count=False,out
 
         if visit_count == False:
             empty = empty.set_index(['Facility','Element'])
-            empty.to_excel('../data/processed/'+outfile+'.xlsx')
+            empty.to_excel(outfile+'.xlsx')
 
         else:
             empty = empty.set_index(['Facility','Visit Count','Element'])
-            empty.to_excel('../data/processed/'+outfile+'.xlsx')
+            empty.to_excel(outfile+'.xlsx')
             
             
     # Keep track of end time
@@ -2091,7 +2060,7 @@ def Visualization_interactive(df_before,df_after,str_date_list,priority='both_co
         # Read in optional user argument to see if they want to save file.  I customized the name to be as descriptive as possible.
         if outfile == True:
             filename = ('_to_'.join(str_date_list)+'_priorty'+pri+'.html').replace(' ','')
-            fig.write_html('../figures/'+filename)
+            fig.write_html(filename)
 
     # Keep track of end time
     end_time = time.time()
@@ -2305,7 +2274,7 @@ def heatmap_compNvalid(df, outfilename=None, daterange=None, hospitals='IHA'):
 
     # Write to outfile
     if outfilename:
-        fig.write_html("../figures/"+outfilename+".html")
+        fig.write_html(outfilename+".html")
 
         
     return comp,valids
